import tkinter as tk
from tkinter import filedialog, messagebox
import pandas as pd
from bs4 import BeautifulSoup
from datetime import datetime
import os

# Funktion: HTML zu Excel
def html_to_excel():
    # Wähle die HTML-Datei aus
    html_file = filedialog.askopenfilename(title="Wähle eine HTML-Datei", filetypes=[("HTML files", "*.html")])
    if not html_file:
        return

    # Parse HTML und extrahiere Daten
    with open(html_file, 'r', encoding='utf-8') as f:
        html_data = f.read()
    
    soup = BeautifulSoup(html_data, "html.parser")
    links = soup.find_all('a')

    data = []
    for link in links:
        href = link.get('href')
        tags = link.get('tags', '')
        add_date_unix = int(link.get('add_date'))
        add_date = datetime.utcfromtimestamp(add_date_unix).strftime('%Y-%m-%d %H:%M:%S')
        description = link.get_text()

        data.append([href, tags, add_date, description])

    # Erstelle DataFrame und speichere als Excel
    df = pd.DataFrame(data, columns=['URL', 'Tags', 'Add Date', 'Description'])
    output_file = filedialog.asksaveasfilename(defaultextension=".xlsx", filetypes=[("Excel files", "*.xlsx")])
    
    if output_file:
        df.to_excel(output_file, index=False)
        messagebox.showinfo("Erfolg", f"Excel-Datei erfolgreich unter '{output_file}' gespeichert.")

# Funktion: Excel zu HTML
def excel_to_html():
    # Wähle die Excel-Datei aus
    excel_file = filedialog.askopenfilename(title="Wähle eine Excel-Datei", filetypes=[("Excel files", "*.xlsx")])
    if not excel_file:
        return
    
    df = pd.read_excel(excel_file)

    # Starte HTML-Gerüst
    html_content = """
    <!DOCTYPE NETSCAPE-Bookmark-file-1>
    <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8">
    <TITLE>Bookmarks</TITLE><DL><p>
    """

    # Iteriere über die Zeilen des DataFrame und erstelle HTML
    for index, row in df.iterrows():
        url = row['URL']
        tags = row['Tags']
        add_date = int(pd.Timestamp(row['Add Date']).timestamp())
        description = row['Description']
        
        html_content += f'<DT><A HREF="{url}" TAGS="{tags}" ADD_DATE="{add_date}">{description}</A>\n'

    html_content += "</p></DL>"

    # Speichere die HTML-Datei
    output_file = filedialog.asksaveasfilename(defaultextension=".html", filetypes=[("HTML files", "*.html")])
    
    if output_file:
        with open(output_file, 'w', encoding='utf-8') as f:
            f.write(html_content)
        messagebox.showinfo("Erfolg", f"HTML-Datei erfolgreich unter '{output_file}' gespeichert.")

# Hauptfenster erstellen
root = tk.Tk()
root.title("HTML <-> Excel Konverter")

# Frame und Buttons
frame = tk.Frame(root, padx=20, pady=20)
frame.pack()

label = tk.Label(frame, text="Wähle eine Option:", font=("Arial", 14))
label.pack(pady=10)

btn_html_to_excel = tk.Button(frame, text="HTML zu Excel", command=html_to_excel, width=20, height=2)
btn_html_to_excel.pack(pady=5)

btn_excel_to_html = tk.Button(frame, text="Excel zu HTML", command=excel_to_html, width=20, height=2)
btn_excel_to_html.pack(pady=5)

# GUI starten
root.mainloop()

